@@ -8,11 +8,12 @@ from typing import Union
 
 class ID:
     """Base microservice endpoint identifier"""
-    def __init__(self, service: str, app: str, view_set: Union[None, str], action=None):
-        self._service = service
-        self._app = app
-        self._view_set = view_set
-        self._action = action
+    _service = None
+    _app = None
+    _view_set = None
+    _action = None
+
+    def __init__(self):
         self._lookup_field_value = None
         super().__init__()
 
