@@ -1,4 +1,4 @@
-__all__ = ('LoanPoint', 'LoanPaginationNonePoint', 'PayPoint',)
+__all__ = ('LoanPoint', 'PayPoint', 'ClosedLoanPoint')
 
 from typing import OrderedDict, Union
 
@@ -49,33 +49,64 @@ class LoanReadContract(LoanCreateContract):
     comment = serializers.CharField(max_length=2048, allow_blank=True)
 
 
-class LoanPaginationNoneReadContract(LoanReadContract):
-    pagination = None
-
-
 class PayUpdateContract(Contract):
     bank_card_id = serializers.IntegerField()
 
 
+class ClosedLoanContract(Contract):
+    OPEN = "OPEN"  # Customer received money
+    OVERDUE = "OVERDUE"
+    STOP_INTEREST = "STOP_INTEREST"
+    DEFAULT = "DEFAULT"
+    CLOSED = "CLOSED"
+    STATUS_CHOICES = {
+        (OPEN, "Open"),
+        (OVERDUE, "Overdue"),
+        (STOP_INTEREST, "Stop interest"),
+        (DEFAULT, "Default"),
+        (CLOSED, "Closed")
+    }
+
+    id = serializers.IntegerField(min_value=1)
+    created = serializers.DateTimeField()
+    updated = serializers.DateTimeField()
+    order = serializers.IntegerField(min_value=1)
+    interests_charged_date = serializers.DateField(allow_null=True)
+    status = serializers.ChoiceField(choices=STATUS_CHOICES)
+    sign = serializers.IntegerField()
+    ip = serializers.IPAddressField(protocol="IPv4")
+    document = serializers.CharField(max_length=256, allow_blank=True)
+    comment = serializers.CharField(max_length=2048, allow_blank=True)
+
+    amount = serializers.DecimalField(max_digits=16, decimal_places=0)
+    period = serializers.IntegerField(min_value=0)
+    expiry_date = serializers.DateField()
+    expiry_period = serializers.DateField()
+    body_balance = serializers.DecimalField(max_digits=16, decimal_places=0)
+    body_paid = serializers.DecimalField(max_digits=16, decimal_places=0)
+    interests_total = serializers.DecimalField(max_digits=16, decimal_places=0)
+    interests_paid = serializers.DecimalField(max_digits=16, decimal_places=0)
+    interests_balance = serializers.DecimalField(max_digits=16, decimal_places=0)
+
+
 class LoanID(ID):
     _service = SERVICE
     _app = 'loans'
     _view_set = 'loan'
 
 
-class LoanPaginationNoneID(ID):
-    _service = SERVICE
-    _app = 'loans'
-    _view_set = 'loan'
-    _action = 'pagination_none'
-
-
 class PayID(ID):
     _service = SERVICE
     _app = 'loans'
     _view_set = 'pay'
 
 
+class ClosedLoanID(ID):
+    _service = SERVICE
+    _app = 'loans'
+    _view_set = 'closed_loan'
+
+
 class LoanPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _point_id = LoanID()
     _read_contract = LoanReadContract
@@ -89,11 +120,11 @@ class LoanPoint(ListPointMixin, CreatePointMixin, ContractPoint):
         return objects[-1] if len(objects) > 0 else None
 
 
-class LoanPaginationNonePoint(ListPointMixin, ContractPoint):
-    _point_id = LoanPaginationNoneID()
-    _read_contract = LoanPaginationNoneReadContract
-
-
 class PayPoint(UpdatePointMixin, ContractObjectPoint):
     _point_id = PayID()
     _update_contract = PayUpdateContract
+
+
+class ClosedLoanPoint(ListPointMixin, ContractPoint):
+    _point_id = ClosedLoanID()
+    _read_contract = ClosedLoanContract
