@@ -146,12 +146,17 @@ class Point:
 class ObjectPoint(Point):
     """For one object endpoints"""
 
-    def __init__(self, user: User, lookup_field_value: Union[None, str, int] = None, is_async: bool = False):
+    def __init__(self,
+                 user: User,
+                 lookup_field_value: Union[None, str, int] = None,
+                 is_async: bool = False,
+                 timeout: tuple = (30, 30),
+                 ):
         if lookup_field_value is None:
             raise LookupFieldValueNone('lookup_field_value not filled')
         self._lookup_field_value = lookup_field_value
         self._point_id.lookup_field_value = lookup_field_value
-        super().__init__(user, is_async)
+        super().__init__(user, is_async, timeout)
 
     def _put(self, payload: dict):
         self._response = self._client.put(payload=payload)
