@@ -4,7 +4,7 @@ from django.core.validators import RegexValidator
 
 from expressmoney.api import *
 
-SERVICE_NAME = 'storage'
+SERVICE = 'storage'
 
 
 class UserFileReadContract(Contract):
@@ -16,17 +16,25 @@ class UserFileReadContract(Contract):
     public_url = serializers.URLField(allow_null=True)
 
 
-storage_storage_user_file = ID(SERVICE_NAME, 'storage', 'user_file')
-storage_storage_upload_file = ID(SERVICE_NAME, 'storage', 'upload_file/')
+class UserFileID(ID):
+    _service = SERVICE
+    _app = 'storage'
+    _view_set = 'user_file'
+
+
+class UploadFileID(ID):
+    _service = SERVICE
+    _app = 'storage'
+    _view_set = 'upload_file/'
 
 
 class UserFilePoint(ListPointMixin, ContractPoint):
     _read_contract = UserFileReadContract
-    _point_id = storage_storage_user_file
+    _point_id = UserFileID()
     _app = 'storage'
     _point = 'user_file'
 
 
 class UploadFilePoint(UploadFilePointMixin, ContractPoint):
-    _point_id = storage_storage_upload_file
+    _point_id = UploadFileID()
     _read_contract = None
